@@ -28,8 +28,6 @@
 #include "ev-document-misc.h"
 #include "synctex_parser.h"
 
-#define EV_DOCUMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), EV_TYPE_DOCUMENT, EvDocumentPrivate))
-
 enum {
 	PROP_0,
 	PROP_MODIFIED
@@ -82,7 +80,7 @@ static gboolean        _ev_document_support_synctex (EvDocument *document);
 static GMutex ev_doc_mutex;
 static GMutex ev_fc_mutex;
 
-G_DEFINE_ABSTRACT_TYPE (EvDocument, ev_document, G_TYPE_OBJECT)
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (EvDocument, ev_document, G_TYPE_OBJECT)
 
 GQuark
 ev_document_error_quark (void)
@@ -175,7 +173,7 @@ ev_document_get_property (GObject     *object,
 static void
 ev_document_init (EvDocument *document)
 {
-	document->priv = EV_DOCUMENT_GET_PRIVATE (document);
+	document->priv = ev_document_get_instance_private (document);
 
 	/* Assume all pages are the same size until proven otherwise */
 	document->priv->uniform = TRUE;
@@ -186,8 +184,6 @@ ev_document_class_init (EvDocumentClass *klass)
 {
 	GObjectClass *g_object_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (g_object_class, sizeof (EvDocumentPrivate));
-
 	klass->get_page = ev_document_impl_get_page;
 	klass->get_info = ev_document_impl_get_info;
 	klass->get_backend_info = NULL;
@@ -858,6 +854,14 @@ _ev_document_get_info (EvDocument *document)
 	return klass->get_info (document);
 }
 
+/**
+ * ev_document_get_info:
+ * @document: a #EvDocument
+ *
+ * Returns the #EvDocumentInfo for the document.
+ *
+ * Returns: (transfer none): a #EvDocumentInfo
+ */
 EvDocumentInfo *
 ev_document_get_info (EvDocument *document)
 {
